Pdef releases
=============

### 1.2.0 (2014-02-11)
- Simpler RPC, #395.

### 1.1.2 (2014-01-15)
- Return definition referenced types as a set, #393.
- Assert base is a message when adding subtypes, #388.

### 1.1.1 (2014-01-14)
- Report not found source files, #392.
- No exception inheritance in subinterfaces, #391.
- Polymorphic message method in test interface, #390.
- Fix stripping * and white space from docstrings, #389.

### 1.1.0 (2013-12-22)
- Namespaces, #379.
- New generators CLI, #374.
- Default package dependency paths #378.
- Better source files, #380.

### 1.0.1 (2013-12-18)
- UTF-8 support in URL sources, #372.
- Prevent polymorphic inheritance of messages from another packages, #366.
- Null values in HTTP RPC specification, #376.

### 1.0.0 (2013-12-04)
- Initial release
